import ActionAlert from "./ActionAlert.js";
import ActionCallback from "./ActionCallback.js";
import ActionConsole from "./ActionConsole.js";
import ActionModal from "./ActionModal.js";
import ActionNotice from "./ActionNotice.js";
import ActionStop from "./ActionStop.js";
import ActionSubmit from "./ActionSubmit.js";

/**
 * Actions.
 * 
 * @since 1.0.0
 */
export default class Actions {
    /**
     * Constructor.
     * 
     * @param actionsData Actions data.
     * @param form Form instance.
     * 
     * @since 1.0.0
     */
    constructor(actionsData, formValues = [] ) {
        this.actions = [];

        actionsData.forEach(actionData => {
            let action;
            switch (actionData.type) {                
                case "alert":
                    action = new ActionAlert(actionData);
                    this.actions.push(action);
                    break;
                case "callback":
                    action = new ActionCallback(actionData);
                    this.actions.push(action);
                    break;
                case "console":
                    action = new ActionConsole(actionData);
                    this.actions.push(action);
                    break;             
                case "modal":
                    action = new ActionModal(actionData);
                    this.actions.push(action);
                    break;
                case "notice":
                    action = new ActionNotice(actionData);
                    this.actions.push(action);
                    break;              
                case "stop":
                    action = new ActionStop();
                    this.actions.push(action);
                    break;
                case "submit":
                    action = new ActionSubmit(actionData, formValues);
                    this.actions.push(action);
                    break;
                default:
                    throw new Error("Action type '" + actionData.type + "' does not exist.");
            }
        });
    }

    /**
     * Run all actions.
     * 
     * @return {boolean} True if all actions were executed successfully.
     * 
     * @since 1.0.0
     */
    execute() {
        let execute = true;
        this.actions.forEach(action => {
            if (execute) {
                execute = action.execute();
            }
        } );

        return execute;
    }
}