import Button from "../Helpers/Button.js";

/**
 * Modal class.
 * 
 * @since 1.0.0
 */
export default class Modal {
    /**
     * Show modal.
     * 
     * @param modalData Modal data.
     * 
     * @since 1.0.0
     */
    constructor(modalData) {
        this.modalData = modalData;
    }

    /**
     * Is modal visible.
     * 
     * @returns True if modal is visible, false otherwise.
     * 
     * @since 1.0.0
     */
    isVisible()  {
        return this.modalData !== undefined && this.modalData.visibility === "show";
    }

    /**
     * Modal title.
     * 
     * @returns Modal title.
     * 
     * @since 1.0.0
     */
    getTitle() {
        return this.modalData.title;
    }

    /**
     * Modal body.
     * 
     * @returns Modal body.
     * 
     * @since 1.0.0
     */
    getBody() {
        return this.modalData.body;
    }

    /**
     * Get buttons.
     * 
     * @returns Modal buttons.
     * 
     * @since 1.0.0
     */
    getButtons() {
        let buttons = [];

        if( this.modalData.buttons === undefined ) {
            return undefined;
        }

        this.modalData.buttons.forEach(buttonData => {
            buttons.push(new Button(buttonData));            
        });

        return buttons;
    }

    /**
     * Hide modal.
     * 
     * @since 1.0.0
     */
    dismiss() {
        // Reset modal data.
        this.modalData = undefined;
    }

    /**
     * Check if modal exists.
     * 
     * @returns {boolean} True if modal exists, false otherwise.
     * 
     * @since 1.0.0
     */
    exists() {
        return this.modalData !== undefined;
    }
}