/**
 * Field class.
 *
 * Should be extended by all field types and not used directly.
 *
 * @since 1.0.0
 */
export default class Field {
    /**
     * Initializing field.
     *
     * @param fieldData  - Field data.
     * @param {Array} formValues - Form values.
     *
     * @since 1.0.0
     */
    constructor(fieldData: any, formValues: any[]);
    formValues: any[];
    id: any;
    type: any;
    label: any;
    prefix: any;
    suffix: any;
    placeholder: any;
    options: any;
    help: any;
    valueDefault: any;
    valueCallback: ValueCallback;
    validated: boolean;
    errors: any[];
    validations: any;
    replacements: any;
    conditions: any;
    labelClasses: CSSClasses;
    inputClasses: CSSClasses;
    classes: CSSClasses;
    size: any;
    /**
     * Updating field assets
     *
     * @since 1.0.0
     */
    updateAssets(): void;
    /**
     * Replace a value by field replacements.
     *
     * @param {any} value - Value to be replaced.
     *
     * @returns {any} Replaced value.
     *
     * @since 1.0.0
     */
    replace(value: any): any;
    /**
     * Checks if conditions for displaying field are met.
     *
     * @returns True if conditions are met, false otherwise.
     *
     * @since 1.0.0
     */
    conditionsFulfilled(): boolean;
    /**
     * Get errors of the field.
     *
     * @returns {Array} Erros of the field.
     *
     * @since 1.0.0
     */
    getErrors(): any[];
    /**
     * Is field visible.
     *
     * @returns {boolean} True if field is visible, false otherwise.
     *
     * @since 1.0.0
     */
    isVisible(): boolean;
    /**
     * Is field completed.
     *
     * @returns {boolean} True if field is completed, false otherwise.
     *
     * @since 1.0.0
     */
    isComplete(): boolean;
    /**
     * Is field validated.
     *
     * @returns {boolean} True if field is validated, false otherwise.
     *
     * @since 1.0.0
     */
    isValidated(): boolean;
    /**
     * Validate field.
     *
     * @returns True if field is valid, false otherwise.
     *
     * @since 1.0.0
     */
    validate(): void;
}
import ValueCallback from '../Helpers/ValueCallback.js';
import CSSClasses from '../Helpers/CSSClasses.js';
