import Validations from '../Helpers/Validations.js';

import Field from './Field.js';
import { fieldStore } from '../../Stores/FieldStore.js';

/**
 * SingleField class.
 * 
 * @since 1.0.0
 */
export default class SingleField extends Field {
    /**
     * Initializing field.
     * 
     * @param fieldData  Field data.
     * @param {Array} formValues Form values.
     * 
     * @since 1.0.0
     */
    constructor(fieldData, formValues = []) {
        super(fieldData, formValues);

        if( this.valueDefault !== undefined && this.getValue() === undefined ) {
            this.formValues[this.id] = this.valueDefault;
        }
    }

    /**
     * Doing form things and get value of the field.
     * 
     * @returns {any} Value of the field.
     * 
     * @since 1.0.0
     */
    getValue() {
        return this.formValues[this.id];
    }

    /**
     * Doing form things and g set value of the field.
     * 
     * @param {any} value Value to set.
     * 
     * @since 1.0.0
     */
    setValue(value) {
        value = this.replace(value); // Auto replacements e.g. for points replace with comma.

        if( this.formValues[this.id] === value ) {
            console.log('Same value');
            return value;
        }

        this.formValues[this.id] = value;       
        console.log( 'validating', this.id, value,  this.validate() );
		this.updateAssets();
        
        fieldStore.set(this);

        return value;
    }

    /**
     * Validate field values and set errors.
     * 
     * @returns {boolean} True if field is valid.
     * 
     * @since 1.0.0
     */
    validate() {
        if( this.validations === undefined ) {
            return true;
        }
        
        let validations = new Validations(this.validations);
        validations.validate(this.getValue());
        this.validated = true;
        this.errors = validations.getErrors();
        return this.errors.length === 0;
    }
}