import CSSClasses from '../Helpers/CSSClasses.js';
import Conditions from '../Helpers/Conditions.js';

import MultipleField from '../Fields/MultipleField.js';
import SingleField from '../Fields/SingleField.js';

/**
 * Class Fieldset.
 * 
 * @since 1.0.0
 */
export default class Fieldset {
    /**
     * Constructor.
     * 
     * @param form Form object.
     * 
     * @since 1.0.0
     */
    constructor(fieldsetData, formValues = []) {
        this.id = fieldsetData.id;
        this.fields = [];

        if( fieldsetData.legend !== undefined ) this.legend = fieldsetData.legend;
        if( fieldsetData.nextFieldset !== undefined ) this.nextFieldset = fieldsetData.nextFieldset;
        if( fieldsetData.prevFieldset !== undefined ) this.prevFieldset = fieldsetData.prevFieldset;

        fieldsetData.fields.forEach(fieldData => {
            if( fieldData.multiple === true ) {
                this.fields.push(new MultipleField(fieldData, formValues));
            } else {
                this.fields.push(new SingleField(fieldData, formValues));
            }
        });

        this.conditions = new Conditions(fieldsetData.conditions, formValues);
        this.classes = new CSSClasses(fieldsetData.classes);
        this.legendClasses = new CSSClasses(fieldsetData.legendClasses);
        this.fieldsClasses = new CSSClasses(fieldsetData.fieldsClasses);
    }    

    /**
     * Has next fieldset.
     * 
     * @returns {boolean} True if has next fieldset, false otherwise.
     * 
     * @since 1.0.0
     */
    hasNext() {
        return this.nextFieldset !== undefined;
    }

    /**
     * Has previous fieldset.
     * 
     * @returns {boolean} True if has previous fieldset, false otherwise.
     * 
     * @since 1.0.0
     */
    hasPrev() {
        return this.prevFieldset !== undefined;
    }

    /**
     * Has previous fieldset.
     * 
     * @returns {boolean} True if has previous fieldset, false otherwise.
     * 
     * @since 1.0.0
     */
    isComplete() {
        let complete = true;
        this.fields.forEach( field => {
            if( field.isComplete() !== true ) {
                complete = false;                
            }
        })

        return complete;
    }
}