/**
 * Class Form.
 *
 * @since 1.0.0
 */
export default class Form {
    /**
     * Initializing form data.
     *
     * @param formData - Form data from JSON file.
     *
     * @since 1.0.0
     */
    constructor(formData: any, formValues?: any[]);
    id: any;
    showTabs: any;
    currentFieldsetId: any;
    formValues: any[];
    fieldsets: any[];
    classes: CSSClasses;
    navigationData: any;
    events: Events;
    /**
     * Execute triggers.
     *
     * @return boolean True if all events were executed successfully.
     *
     * @since 1.0.0
     */
    executeEvents(trigger: any): boolean;
    /**
     * Execute callbacks.
     *
     * @param trigger Trigger to execute.
     *
     * @since 1.0.0
     */
    executeFieldCallbacks(trigger: any): void;
    /**
     * Set current fieldset.
     *
     * @param fieldsetId Id of fieldset.
     *
     * @since 1.0.0
     */
    setCurrentFieldset(fieldsetId: any): void;
    /**
     * Check if fieldset exists.
     *
     * @param fieldsetId Fieldset id.
     *
     * @returns boolean True if fieldset exists, false if not.
     *
     * @since 1.0.0
     */
    fieldsetExists(fieldsetId: any): boolean;
    /**
     * Get current fieldset id.
     *
     * @returns string Current fieldset id.
     *
     * @since 1.0.0
     */
    getCurrentFieldsetId(): any;
    /**
     * Get current fieldset.
     *
     * @returns {Fieldset} Fieldset object.
     *
     * @since 1.0.0
     */
    getCurrentFieldset(): Fieldset;
    /**
     * Get fieldset by id.
     *
     * @param fieldsetId Fieldset id.
     *
     * @returns Fieldset object.
     *
     * @since 1.0.0
     */
    getFieldset(fieldsetId: any): any;
    /**
     * Get value by field id.
     *
     * @param fieldId Field id.
     *
     * @returns {any} Value of field.
     *
     * @since 1.0.0
     */
    getValue(fieldId: any): any;
    /**
     * Set value by field id.
     *
     * @param {string} fieldId Field id.
     * @param {any} value Value to set.
     *
     * @since 1.0.0
     */
    setValue(fieldId: string, value: any): void;
    /**
     * Get form values.
     *
     * @returns [] Form values.
     *
     * @since 1.0.0
     */
    getValues(): any[];
    /**
     * Has navigation data (CSS etc).
     *
     * @returns {boolean} True if form has navigation data, false if not.
     *
     * @since 1.0.0
     */
    hasNavigationData(): boolean;
}
import CSSClasses from '../Helpers/CSSClasses.js';
import Events from '../Actions/Events.js';
import Fieldset from './Fieldset.js';
