/**
 * Callback class.
 * 
 * @since 1.0.0
 */
export default class Callback {
    /**
     * Constructor.
     * 
     * @param args Callback arguments.
     * 
     * @since 1.0.0
     */
    constructor(callback) {
        this.method = callback.method;

        if( callback.args !== undefined ) {
            this.args = callback.args.slice();
        } else {
            this.args = [];
        }
    }

    /**
     * Execute callback.
     * 
     * @returns any Callback return value.
     * 
     * @since 1.0.0
     */
    execute() {
        if( globalThis[this.method] === undefined ) {
            console.error(`Callback "${this.method}" does not exist.`);
            return;
        }

        let returnValue;
        if( this.args.length > 0 ) {
            returnValue = globalThis[this.method](...this.args);
        } else {
            returnValue = globalThis[this.method]();
        }

        return returnValue;
    }
}